==> ejc-middlemeasurement-impl-3.0.0-20221219.062630-293-sources.jar: com/ejianc/business/middlemeasurement/bean/ConsultotherodetailEntity.java <==
package com.ejianc.business.middlemeasurement.bean;

import java.math.BigDecimal;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;

/**
 * 咨询及其他类合同过程结算单-其他扣款
 *
 * @author generator
 *
 */
 @TableName("ejc_middlemeasurement_consultotherodetail")
public class ConsultotherodetailEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;

    @TableField(value="mid")
    private Long mid; // 主表id
    @TableField(value="bill_state")
    private Integer billState; // 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
    @TableField(value="sort")
    private String sort; // 序号
    @TableField(value="expense_name")
    private String expenseName; // 费用名称
    @TableField(value="unit")
    private String unit; // 单位
    @TableField(value="o_quantity")
    private java.math.BigDecimal oQuantity; // 数量
    @TableField(value="o_unit_price")
    private java.math.BigDecimal oUnitPrice; // 单价
    @TableField(value="amounts")
    private java.math.BigDecimal amounts; // 金额
    @TableField(value="remarks")
    private String remarks; // 备注




    /**
     * 主表id
     */
    public Long getMid() {
        return mid;
    }

    /**
     * 主表id
     */
    public void setMid(Long mid) {
        this.mid = mid;
    }
    /**
     * 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
     */
    public Integer getBillState() {
        return billState;
    }

    /**
     * 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
     */
    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    /**
     * 序号
     */
    public String getSort() {
        return sort;
    }

    /**
     * 序号
     */
    public void setSort(String sort) {
        this.sort = sort;
    }
    /**
     * 费用名称
     */
    public String getExpenseName() {
        return expenseName;
    }

    /**
     * 费用名称
     */
    public void setExpenseName(String expenseName) {
        this.expenseName = expenseName;
    }
    /**
     * 单位
     */
    public String getUnit() {
        return unit;
    }

    /**
     * 单位
     */
    public void setUnit(String unit) {
        this.unit = unit;
    }

    public BigDecimal getoQuantity() {
        return oQuantity;
    }

    public void setoQuantity(BigDecimal oQuantity) {
        this.oQuantity = oQuantity;
    }

    public BigDecimal getoUnitPrice() {
        return oUnitPrice;
    }

    public void setoUnitPrice(BigDecimal oUnitPrice) {
        this.oUnitPrice = oUnitPrice;
    }

    /**
     * 金额
     */
    public java.math.BigDecimal getAmounts() {
        return amounts;
    }

    /**
     * 金额
     */
    public void setAmounts(java.math.BigDecimal amounts) {
        this.amounts = amounts;
    }
    /**
     * 备注
     */
    public String getRemarks() {
        return remarks;
    }

    /**
     * 备注
     */
    public void setRemarks(String remarks) {
        this.remarks = remarks;
    }

}

==> ejc-middlemeasurement-impl-3.0.0-20230130.110416-335-sources.jar: com/ejianc/business/middlemeasurement/bean/ConsultotherodetailEntity.java <==
package com.ejianc.business.middlemeasurement.bean;

import java.math.BigDecimal;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;

/**
 * 咨询及其他类合同过程结算单-其他扣款
 *
 * @author generator
 *
 */
 @TableName("ejc_middlemeasurement_consultotherodetail")
public class ConsultotherodetailEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;

    @TableField(value="mid")
    private Long mid; // 主表id
    @TableField(value="bill_state")
    private Integer billState; // 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
    @TableField(value="sort")
    private String sort; // 序号
    @TableField(value="expense_name")
    private String expenseName; // 费用名称
    @TableField(value="unit")
    private String unit; // 单位
    @TableField(value="o_quantity")
    private java.math.BigDecimal oQuantity; // 数量
    @TableField(value="o_unit_price")
    private java.math.BigDecimal oUnitPrice; // (除税)单价
    @TableField(value="amounts")
    private java.math.BigDecimal amounts; // (除税)金额
    @TableField(value="o_tax_unit_price")
    private java.math.BigDecimal oTaxUnitPrice; // (含税)单价
    @TableField(value="tax_amounts")
    private java.math.BigDecimal taxAmounts; // (含税)金额
    @TableField(value="remarks")
    private String remarks; // 备注




    /**
     * 主表id
     */
    public Long getMid() {
        return mid;
    }

    /**
     * 主表id
     */
    public void setMid(Long mid) {
        this.mid = mid;
    }
    /**
     * 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
     */
    public Integer getBillState() {
        return billState;
    }

    /**
     * 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
     */
    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    /**
     * 序号
     */
    public String getSort() {
        return sort;
    }

    /**
     * 序号
     */
    public void setSort(String sort) {
        this.sort = sort;
    }
    /**
     * 费用名称
     */
    public String getExpenseName() {
        return expenseName;
    }

    /**
     * 费用名称
     */
    public void setExpenseName(String expenseName) {
        this.expenseName = expenseName;
    }
    /**
     * 单位
     */
    public String getUnit() {
        return unit;
    }

    /**
     * 单位
     */
    public void setUnit(String unit) {
        this.unit = unit;
    }

    public BigDecimal getoQuantity() {
        return oQuantity;
    }

    public void setoQuantity(BigDecimal oQuantity) {
        this.oQuantity = oQuantity;
    }

    public BigDecimal getoUnitPrice() {
        return oUnitPrice;
    }

    public void setoUnitPrice(BigDecimal oUnitPrice) {
        this.oUnitPrice = oUnitPrice;
    }

    /**
     * 金额
     */
    public java.math.BigDecimal getAmounts() {
        return amounts;
    }

    /**
     * 金额
     */
    public void setAmounts(java.math.BigDecimal amounts) {
        this.amounts = amounts;
    }
    /**
     * 备注
     */
    public String getRemarks() {
        return remarks;
    }

    /**
     * 备注
     */
    public void setRemarks(String remarks) {
        this.remarks = remarks;
    }

    public BigDecimal getoTaxUnitPrice() {
        return oTaxUnitPrice;
    }

    public void setoTaxUnitPrice(BigDecimal oTaxUnitPrice) {
        this.oTaxUnitPrice = oTaxUnitPrice;
    }

    public BigDecimal getTaxAmounts() {
        return taxAmounts;
    }

    public void setTaxAmounts(BigDecimal taxAmounts) {
        this.taxAmounts = taxAmounts;
    }
}
